Attribute VB_Name = "Module1"
Sub Main()
    ' This code demos error handling.
    ' It doesn't do anything useful.
    If iOpenFile(InputBox("Enter the name of a file to open: ")) Then
        MsgBox ("The file opened successfully.")
    Else
        MsgBox ("There was an error opening the file.")
    End If
End Sub

' Opens a file for Input. Returns file number if successful,
' 0 if failure.
Function iOpenFile(sFilename As String) As Integer
     Dim iFilenumber As Integer, iTries As Integer
     ' (1) Turn on error handling.
     On Error GoTo iOpenFileErr
     ' Get a free file number.
     iFilenumber = FreeFile()
     ' (2) Open file. We don't know if the file exists yet,
     ' so might cause an error.
     Open sFilename For Input As iFilenumber
     ' (7) Return file number so user can manipulate file.
     iOpenFile = iFilenumber
     ' Important! Turn off error handling.
     On Error GoTo 0
     ' Clear status bar.
     Application.StatusBar = ""
     ' (8) Important! Exit procedure before the error handler.
     Exit Function
' (3) Label identifies error handler. This label must be unique
' to the workbook.
iOpenFileErr:
     ' Classic way to do this: Select Case on the error code,
     ' with a Case statement for each possibility.
     Select Case Err
          Case 52, 53, 75, 76 ' Bad file name or number,
                              ' file not found, or path error.
               ' (4) Display a status message
               ' indicating the error.
               MsgBox "File not found."
               ' Prompt the user for the file to open.
               sFilename = InputBox("Enter the name of a file to open: ")
               ' If the user chose Cancel...
               If sFilename = "" Then
                    ' Return 0 to indicate that function didn't
                    ' open a file.
                    iOpenFile = 0
                    ' Turn off error handling and exit.
                    On Error GoTo 0
                    Exit Function
               End If
          Case 55 ' File already open by VB for an incompatible
                  ' read/write access.
               ' This shouldn't happen, but if it does, return 0
               ' and exit.
               iOpenFile = 0
               On Error GoTo 0
               Exit Function
          Case 67 ' (5) Too many files are open
               Application.StatusBar = "Too many files or applications open."
               MsgBox "Close one or more files or applications and try again."
               iOpenFile = 0
               On Error GoTo 0
               Exit Function
          Case 70 ' Permission denied.
               Application.StatusBar = "Permission denied."
               MsgBox "You can't open " & sFilename & _
                    ". It requires a password or is in use by another application."
               iOpenFile = 0
               On Error GoTo 0
               Exit Function
          Case 71 ' Disk not ready.
               ' Keep track of the number of tries.
               iTries = iTries + 1
               ' Let the user try twice, but don't beat them
               ' over the head.
               If iTries < 3 Then
                    Application.StatusBar = "Can't read from drive."
                    MsgBox "Make sure the disk is inserted and the drive door is closed."
               ' Fail after second try -- maybe the user changed
               ' his/her mind.
               Else
                    iOpenFile = 0
                    On Error GoTo 0
                    Exit Function
               End If
          Case Else
               ' Report the error, so you can fix it.
               MsgBox "An unanticipated error occurred. Please report " & _
                    "the following information to AppBug: " & Chr$(10) & _
                    "Procedure: iOpenFile" & Chr$(10) & _
                    "Error: " & Err & Error()
                    iOpenFile = 0
                    On Error GoTo 0
               Exit Function
     End Select
     ' (6) You must tell Visual Basic to return after handling
     ' the error.
     Resume
End Function

